@@ -1,10 +1,25 @@
 """This module defines a custom logging handler that publishes log messages to an LSP
 client."""
-
 import logging
 
 from pygls.server import LanguageServer
 
+LOG_LEVELS = {
+    "debug": logging.DEBUG,
+    "error": logging.ERROR,
+    "info": logging.INFO,
+}
+
+
+class LogFilter:
+    """A log filter that accepts message from any of the listed logger names."""
+
+    def __init__(self, names):
+        self.names = names
+
+    def filter(self, record):
+        return any(record.name == name for name in self.names)
+
 
 class LspHandler(logging.Handler):
     """A logging handler that will send log records to an LSP client."""
